@@ -1,7 +1,7 @@
 package Bencher::Scenario::GraphTopologicalSortModules;
 
-our $DATE = '2017-01-25'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2017-04-03'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -15,13 +15,18 @@ our $scenario = {
         {
             module => 'Sort::Topological',
             function => 'toposort',
-            code_template  => 'my $graph = <graph>; Sort::Topological::toposort(sub { @{ $graph->{shift} || [] } }, <unsorted>)',
+            code_template  => 'my $graph = <graph>; Sort::Topological::toposort(sub { @{ $graph->{$_[0]} || [] } }, <unsorted>)',
             result_is_list => 1,
         },
         {
             fcall_template => 'Data::Graph::Util::toposort(<graph>, <unsorted>)',
             result_is_list => 1,
         },
+        {
+            module => 'Algorithm::Dependency',
+            helper_modules => ['Algorithm::Dependency::Source::HoA'],
+            code_template => 'my $deps = Algorithm::Dependency::Source::HoA->new(<graph>); my $dep = Algorithm::Dependency->new(source=>$deps); $dep->schedule_all',
+        },
     ],
 
     datasets => [
@@ -31,13 +36,47 @@ our $scenario = {
                 graph => {
                     'a' => [ 'b', 'c' ],
                     'c' => [ 'x' ],
-                    'b' => [ 'x' ],
+                    'b' => [ 'c', 'x' ],
                     'x' => [ 'y' ],
                     'y' => [ 'z' ],
                     'z' => [ ],
                 },
                 unsorted => ['z', 'a', 'x', 'c', 'b', 'y'],
             },
+            result => ['a', 'b', 'c', 'x', 'y', 'z'],
+        },
+        # hangs Sort::Topological
+        {
+            name => 'cyclic1',
+            args => {
+                graph => {a=>["a"]},
+                unsorted => ['a'],
+            },
+            include_by_default => 0,
+        },
+        {
+            name => 'cyclic2',
+            args => {
+                graph => {a=>["b"], b=>["a"]},
+                unsorted => ['b', 'a'],
+            },
+            include_by_default => 0,
+        },
+        {
+            name => 'cyclic3',
+            args => {
+                graph => {a=>["b"], b=>["c"], c=>["a"]},
+                unsorted => ['a', 'c', 'b'],
+            },
+            include_by_default => 0,
+        },
+        {
+            name => 'cyclic4',
+            args => {
+                graph => {a=>["b","c"], c=>["a","b"], d=>["e"], e=>["f","g","h","a"]},
+                unsorted => ['a', 'b', 'c', 'd', 'e', 'f', 'g', 'h'],
+            },
+            include_by_default => 0,
         },
     ],
 };
@@ -57,7 +96,7 @@ Bencher::Scenario::GraphTopologicalSortModules - Benchmark graph topological sor
 
 =head1 VERSION
 
-This document describes version 0.002 of Bencher::Scenario::GraphTopologicalSortModules (from Perl distribution Bencher-Scenario-GraphTopologicalSortModules), released on 2017-01-25.
+This document describes version 0.003 of Bencher::Scenario::GraphTopologicalSortModules (from Perl distribution Bencher-Scenario-GraphTopologicalSortModules), released on 2017-04-03.
 
 =head1 SYNOPSIS
 
@@ -79,6 +118,8 @@ Packaging a benchmark script as a Bencher scenario makes it convenient to includ
 
 Version numbers shown below are the versions used when running the sample benchmark.
 
+L<Algorithm::Dependency> 1.110
+
 L<Data::Graph::Util> 0.002
 
 L<Sort::Topological> 0.02
@@ -91,7 +132,7 @@ L<Sort::Topological> 0.02
 
 Code template:
 
- my $graph = <graph>; Sort::Topological::toposort(sub { @{ $graph->{shift} || [] } }, <unsorted>)
+ my $graph = <graph>; Sort::Topological::toposort(sub { @{ $graph->{$_[0]} || [] } }, <unsorted>)
 
 
 
@@ -103,6 +144,14 @@ Function call template:
 
 
 
+=item * Algorithm::Dependency (perl_code)
+
+Code template:
+
+ my $deps = Algorithm::Dependency::Source::HoA->new(<graph>); my $dep = Algorithm::Dependency->new(source=>$deps); $dep->schedule_all
+
+
+
 =back
 
 =head1 BENCHMARK DATASETS
@@ -115,7 +164,7 @@ Function call template:
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17.3 >>, OS kernel: I<< Linux version 3.19.0-32-generic >>.
+Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
 
 Benchmark with default options (C<< bencher -m GraphTopologicalSortModules >>):
 
@@ -123,21 +172,23 @@ Benchmark with default options (C<< bencher -m GraphTopologicalSortModules >>):
  +-----------------------------+-----------+-----------+------------+---------+---------+
  | participant                 | rate (/s) | time (μs) | vs_slowest |  errors | samples |
  +-----------------------------+-----------+-----------+------------+---------+---------+
- | Sort::Topological::toposort |     78300 |      12.8 |          1 | 6.7e-09 |      20 |
- | Data::Graph::Util::toposort |     81000 |      12   |          1 | 1.3e-08 |      21 |
+ | Algorithm::Dependency       |     16700 |      60   |       1    | 2.5e-08 |      23 |
+ | Sort::Topological::toposort |     16800 |      59.6 |       1.01 | 2.5e-08 |      23 |
+ | Data::Graph::Util::toposort |     58700 |      17   |       3.52 | 6.7e-09 |      20 |
  +-----------------------------+-----------+-----------+------------+---------+---------+
 
 
 Benchmark module startup overhead (C<< bencher -m GraphTopologicalSortModules --module-startup >>):
 
  #table2#
- +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
- | participant         | proc_private_dirty_size (kB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
- +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
- | Data::Graph::Util   | 840                          | 4.1                | 16             |       7.7 |                    3.4 |        1   | 4.6e-05 |      20 |
- | Sort::Topological   | 972                          | 4.4                | 16             |       7.6 |                    3.3 |        1   |   3e-05 |      20 |
- | perl -e1 (baseline) | 992                          | 4.3                | 16             |       4.3 |                    0   |        1.8 | 6.9e-06 |      20 |
- +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
+ +-----------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
+ | participant           | proc_private_dirty_size (MB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
+ +-----------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
+ | Algorithm::Dependency | 0.82                         | 4.1                | 20             |      16   |                   10.5 |        1   | 2.8e-05 |      20 |
+ | Sort::Topological     | 0.95                         | 4.4                | 20             |       9   |                    3.5 |        1.8 | 2.4e-05 |      20 |
+ | Data::Graph::Util     | 1.7                          | 5.2                | 25             |       8.7 |                    3.2 |        1.8 | 1.6e-05 |      20 |
+ | perl -e1 (baseline)   | 0.97                         | 4.4                | 20             |       5.5 |                    0   |        2.9 | 2.5e-05 |      24 |
+ +-----------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
 
 
 To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
@@ -164,7 +215,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
